( cd usr/lib ; rm -rf libgtkhtml-3.14.so )
( cd usr/lib ; ln -sf libgtkhtml-3.14.so.19.1.0 libgtkhtml-3.14.so )
( cd usr/lib ; rm -rf libgtkhtml-editor.so )
( cd usr/lib ; ln -sf libgtkhtml-editor.so.0.0.0 libgtkhtml-editor.so )
( cd usr/lib ; rm -rf libgtkhtml-editor.so.0 )
( cd usr/lib ; ln -sf libgtkhtml-editor.so.0.0.0 libgtkhtml-editor.so.0 )
( cd usr/lib ; rm -rf libgtkhtml-3.14.so.19 )
( cd usr/lib ; ln -sf libgtkhtml-3.14.so.19.1.0 libgtkhtml-3.14.so.19 )
